@@ -93,7 +93,7 @@ cmsaf.regres <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verb
   vars_data <- list(result = data_placeholder, time_bounds = time_bnds)
 
   nc_format <- get_nc_version(nc34)
-  cmsaf_info <- paste0("cmsaf::cmsaf.regres for variable ",
+  cmsaf_info <- paste0("cmsafops::cmsaf.regres for variable ",
                        file_data$variable$name)
 
   time_data <- time_bnds[1, ]
