@@ -12,6 +12,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of multi-year seasonal maxima is
 #'  written.
@@ -56,6 +58,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_yseasmax.nc")))
-yseasmax <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  yseasx_wrapper(1, var, infile, outfile, nc34, overwrite, verbose)
+yseasmax <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  yseasx_wrapper(1, var, infile, outfile, nc34, overwrite, verbose, nc = nc)
 }
